@@ -11,7 +11,6 @@ import cairo
 import xml.dom.minidom as xmlparser
 import urllib
 import gio
-import inspect
 PATH = "/apps/digghomewidget"
 CATGR = "/apps/digghomewidget/selected_category_int"
 NUM = "/apps/digghomewidget/number_of_stories"
@@ -32,12 +31,16 @@ class diggLoader:
         self.load_thumbnails = True
 
     def parse_and_return(self, daemonfile, result):
+        inputstream = self.stream.read_finish(result)
         try:
-            doc = xmlparser.parseString(self.stream.read_finish(result).read())
+            doc = xmlparser.parseString(inputstream.read())
         except Exception, e:
             doc = None
             print "Can't connect to Digg.com", e
             self.callback(list=None)
+        finally:
+            inputstream.close()
+            
         if doc != None:
             stories = doc.getElementsByTagName("story")
             if len(stories) == 0:
@@ -76,14 +79,14 @@ class diggLoader:
         if topic != "":
             selected = "topic/" + topic + "/"
         if container != "":
+            container = container.replace("&", "_")
             selected = "container/" + container + "/"
-        params = urllib.urlencode({"count":count, "appkey":"http://parasight.propelli.cou.fi/leiska/index.html"})
+        params = urllib.urlencode({"count":count, "appkey":"http://maemo.org/packages/view/digghomewidget/"})
         try:
             self.stream = gio.File("http://services.digg.com/stories/"+selected+hotness+"?%s" % params)
             self.stream.read_async(self.parse_and_return)
         except Exception, e:
-            self.list = None
-            print "Can't connect to Digg.com"
+            print "Can't connect to Digg.com", e
 
 class DiggItemWidget(hildon.Button):
     def __init__(self, item):
@@ -291,7 +294,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
             else:
                 self.checkbox_active = True 
                 self.loader.load_thumbnails = True 
-        print "CAT:", self.category
+#        print "CAT:", self.category
         self.hotness = "Top"
         container = gtk.Alignment(0.0,0.0,1.0,1.0)
         container.set_padding(2,1,0,0)
